@@ -153,14 +153,15 @@ def pip_cert(tmp_path_factory):
     # workaround for https://github.com/pypa/pip/issues/8984 - if the certificate is explicitly set no error can happen
     key = ensure_str("PIP_CERT")
     if key in os.environ:
-        return
-    cert = tmp_path_factory.mktemp("folder") / "cert"
-    import pkgutil
-
-    cert_data = pkgutil.get_data("pip._vendor.certifi", "cacert.pem")
-    cert.write_bytes(cert_data)
-    with change_os_environ(key, str(cert)):
         yield
+    else:
+        cert = tmp_path_factory.mktemp("folder") / "cert"
+        import pkgutil
+
+        cert_data = pkgutil.get_data("pip._vendor.certifi", "cacert.pem")
+        cert.write_bytes(cert_data)
+        with change_os_environ(key, str(cert)):
+            yield
 
 
 @pytest.fixture(autouse=True)
@@ -300,7 +301,7 @@ def is_inside_ci():
 def special_char_name():
     base = "e-$ èрт🚒♞中片-j"
     # workaround for pypy3 https://bitbucket.org/pypy/pypy/issues/3147/venv-non-ascii-support-windows
-    encoding = "ascii" if IS_PYPY and IS_WIN else sys.getfilesystemencoding()
+    encoding = "ascii" if IS_WIN else sys.getfilesystemencoding()
     # let's not include characters that the file system cannot encode)
     result = ""
     for char in base:
